@@ -1,6 +1,5 @@
 from azure.mgmt.resourcegraph.models import QueryRequest
 from chaoslib import Configuration
-
 from pdchaosazure.common.config import load_subscription_id
 
 
@@ -8,11 +7,11 @@ def create_request(
         resource_type: str, user_query: str, experiment_configuration: Configuration) -> QueryRequest:
 
     prepared_query = __prepare(resource_type, user_query)
-    configuration = load_subscription_id(experiment_configuration)
+    subscription_id = load_subscription_id(experiment_configuration)
 
     result = QueryRequest(
         query=prepared_query,
-        subscriptions=[configuration.get('subscription_id')]
+        subscriptions=[subscription_id]
     )
     return result
 
